@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp 'croak';
 
-use version; our $VERSION = qv('0.1.3');    # REMINDER: update Changes
+use version; our $VERSION = qv('0.1.4');    # REMINDER: update Changes
 
 # REMINDER: update dependencies in Build.PL
 use Mojo::Base 'Mojo::Log';
@@ -27,6 +27,9 @@ sub new {
     if ($ENV{MOJO_LOG_LEVEL}) {
         $self->level($ENV{MOJO_LOG_LEVEL});
     }
+    else {
+        $self->level({reverse %MapLevel}->{ $self->{_logger}->level });
+    }
     $self->unsubscribe('message');
     $self->on(message => \&_message);
     return $self;
@@ -170,7 +173,7 @@ Alex Efros  C<< <powerman@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2013-2014 Alex Efros <powerman@cpan.org>.
+Copyright 2013-2015 Alex Efros <powerman@cpan.org>.
 
 This program is distributed under the MIT (X11) License:
 L<http://www.opensource.org/licenses/mit-license.php>
